Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type HangoutsChat ¶
type HangoutsChat struct {
WebhookUrl string
}
func (HangoutsChat) CallHook ¶
func (s HangoutsChat) CallHook(deploy []types.Deploy) error
func (HangoutsChat) ValidatesFields ¶
func (s HangoutsChat) ValidatesFields() error
type NewRelic ¶
NewRelic represents a single struct to notify New Relic about a new deploy
func (NewRelic) CallHook ¶
CallHook will notify New Relic about a new deploy It returns any errors encountered
type Rollbar ¶
Rollbar represents a single struct to notify Rollbar about a new deploy
func (Rollbar) CallHook ¶
CallHook creates a new deploy on Rollbar It returns any errors encountered
type Sentry ¶
type Sentry struct {
Host string
OrganizationSlug string
ProjectSlug string
AuthToken string
Env string
ReleaseVersion string
}
Sentry represents a single struct to notify Sentry about a new deploy
func (Sentry) CallHook ¶
CallHook creates a new release and deploy on Sentry It returns any errors encountered
Source Files
¶
- hangouts_chat.go
- hook.go
- newrelic.go
- rollbar.go
- sentry.go
- slack.go
Click to show internal directories.
Click to hide internal directories.